[polypaudio-commits] r672 - /trunk/src/polyp/def.h

svnmailer-noreply at 0pointer.de svnmailer-noreply at 0pointer.de
Mon Apr 10 10:38:47 PDT 2006


Author: lennart
Date: Mon Apr 10 19:38:46 2006
New Revision: 672

URL: http://0pointer.de/cgi-bin/viewcvs.cgi?rev=672&root=polypaudio&view=rev
Log:
add new PA_STREAM_AUTO_TIMING_UPDATE

Modified:
    trunk/src/polyp/def.h

Modified: trunk/src/polyp/def.h
URL: http://0pointer.de/cgi-bin/viewcvs.cgi/trunk/src/polyp/def.h?rev=672&root=polypaudio&r1=671&r2=672&view=diff
==============================================================================
--- trunk/src/polyp/def.h (original)
+++ trunk/src/polyp/def.h Mon Apr 10 19:38:46 2006
@@ -82,18 +82,16 @@
     PA_STREAM_START_CORKED = 1,       /**< Create the stream corked, requiring an explicit pa_stream_cork() call to uncork it. */
     PA_STREAM_INTERPOLATE_TIMING = 2, /**< Interpolate the latency for
                                        * this stream. When enabled,
                                        * pa_stream_get_latency() and pa_stream_get_time()
                                        * will try to estimate the
                                        * current record/playback time
                                        * based on the local time that
                                        * passed since the last timing
                                        * info update. In addition
                                        * timing update requests are
                                        * issued periodically
                                        * automatically. Using this
                                        * option has the advantage of
                                        * not requiring a whole
                                        * roundtrip when the current
                                        * playback/recording time is
                                        * needed. Consider using this
                                        * option when requesting
@@ -101,7 +99,10 @@
                                        * frequently. This is
                                        * especially useful on long
                                        * latency network
-                                       * connections. */
+                                       * connections. It makes a lot
+                                       * of sense to combine this
+                                       * option with
+                                       * PA_STREAM_AUTO_TIMING_UPDATE. */
     PA_STREAM_NOT_MONOTONOUS = 4,    /**< Don't force the time to
                                       * increase monotonically. If
                                       * this option is enabled,
@@ -118,6 +119,16 @@
                                       * ahead can be corrected
                                       * quickly, without the need to
                                       * wait. */
+    PA_STREAM_AUTO_TIMING_UPDATE = 8 /** If set timing update requests
+                                       * are issued periodically
+                                       * automatically. Combined with
+                                       * PA_STREAM_INTERPOLATE_TIMING
+                                       * you will be able to query the
+                                       * current time and latency with
+                                       * pa_stream_get_time() and
+                                       * pa_stream_get_latency() at
+                                       * all times without a packet
+                                       * round trip.*/
 } pa_stream_flags_t;
 
 /** Playback and record buffer metrics */
@@ -82,18 +82,16 @@
     PA_STREAM_INTERPOLATE_TIMING = 2, /**< Interpolate the latency for
                                        * this stream. When enabled,
-                                       * pa_stream_get_latency() and pa_stream_get_time()
-                                       * will try to estimate the
-                                       * current record/playback time
-                                       * based on the local time that
-                                       * passed since the last timing
-                                       * info update. In addition
-                                       * timing update requests are
-                                       * issued periodically
-                                       * automatically. Using this
-                                       * option has the advantage of
-                                       * not requiring a whole
-                                       * roundtrip when the current
+                                       * pa_stream_get_latency() and
+                                       * pa_stream_get_time() will try
+                                       * to estimate the current
+                                       * record/playback time based on
+                                       * the local time that passed
+                                       * since the last timing info
+                                       * update.  Using this option
+                                       * has the advantage of not
+                                       * requiring a whole roundtrip
+                                       * when the current
                                        * playback/recording time is
                                        * needed. Consider using this




More information about the pulseaudio-commits mailing list